@@ -2,14 +2,12 @@ from pathlib import Path
 import shutil
 
 import numpy as np
-from torchdata.datapipes.iter import IterDataPipe
-from torchdata.datapipes.map import MapDataPipe
 
 from pyPhases.Data import DataNotFound
 from pyPhases.exporter.DataExporter import DataExporter
 
 
-class MemmapRecordExporter(DataExporter, IterDataPipe, MapDataPipe):
+class MemmapRecordExporter(DataExporter):
     includesStorage = True
     batchFillProcess = None
 
