@@ -1,7 +1,6 @@
 import numpy as np
 from sklearn.metrics import confusion_matrix
 
-# from .model.EventManager import EventManager
 
 class Scorer:
     title = "Segmentbasiert"
@@ -9,9 +8,9 @@ class Scorer:
 
     metricNameMap = {}
     addedMetrics = {}
-    
+
     def getMetricDefinition(self, name):
-        
+
         metricDefinition = {
             # init value, useAsBest, biggerIsBetter
             "AUC": [0.5, False, True],
@@ -30,23 +29,22 @@ class Scorer:
             "eventCountDiff": [np.inf, False, False],
             "positiveErrorRatio": [np.inf, True, False],
         }
-        
+
         if name in Scorer.addedMetrics:
             metric = Scorer.addedMetrics[name]
             return [metric["initValue"], metric["useAsBest"], metric["biggerIsBetter"]]
 
         return metricDefinition[name]
-        
-    
+
     @staticmethod
     def registerMetric(metricName, metricFunction, combineFunction, biggerIsBetter=True, useAsBest=True, initValue=None):
-        
+
         Scorer.addedMetrics[metricName] = {
             "score": metricFunction,
             "combine": combineFunction,
             "biggerIsBetter": biggerIsBetter,
             "useAsBest": useAsBest,
-            "initValue": initValue if initValue is not None else 0.0 if biggerIsBetter else np.inf
+            "initValue": initValue if initValue is not None else 0.0 if biggerIsBetter else np.inf,
         }
 
     def getMetricName(self, metricName):
@@ -74,7 +72,7 @@ class Scorer:
         self.addEvents = False
         self.mapping = None
         self.threshold = threshold
-        
+
     def prepareInput(self, inputArray):
         """can be overwritten to tranform tensors to numpy"""
         return inputArray
@@ -149,7 +147,7 @@ class Scorer:
         metricName = self.getMetricName(metricName)
 
         result = None
-              
+
         if metricName in self.addedMetrics:
             truth = np.concatenate([self.recordResult[id]["truth"] for id in self.recordResult], axis=0)
             prediction = np.concatenate([self.recordResult[id]["prediction"] for id in self.recordResult], axis=0)
@@ -198,7 +196,6 @@ class Scorer:
 
         if result is not None:
             self.results[metricName] = result
-            
 
         return self.results[metricName]
 
@@ -313,9 +310,9 @@ class Scorer:
             return self.results[metricName]
 
         result = None
-        
+
         if metricName in self.addedMetrics:
-            self.results[metricName] = self.addedMetrics[metricName]["score"](truth, prediction)  
+            self.results[metricName] = self.addedMetrics[metricName]["score"](truth, prediction)
         elif metricName in ["kappa", "accuracy"]:
             confusion = self.scoreMetric("confusion", truth, prediction)
             k, acc = self.calculateKappaAccFromConfusion(confusion)
